@@ -9,8 +9,8 @@ with 'TestRole::WithGitRepo';
 sub test_startup {
     my $self = shift;
     $self->test_skip(
-        'This test does not run on Travis because of the way it uses git when testing a PR'
-    ) if $ENV{TRAVIS};
+        'This test does not run in CI because of the way it uses git when testing a PR'
+    ) if $ENV{CI};
 }
 
 sub test_question_namespaces {
@@ -29,7 +29,7 @@ sub test_question_namespaces {
 
     $ask = App::GHPT::WorkSubmitter::AskPullRequestQuestions->new(
         merge_to_branch_name => 'master',
-        question_namespaces =>
+        question_namespaces  =>
             [ 'Helper::QuestionNamespace1', 'Helper::QuestionNamespace2' ],
     );
 
